@@ -6,11 +6,12 @@
 */
 
   /* .C calls */
-  extern void estdep(void *, void *, void *, void *, void *, void *);
+extern void estdep(void *, void *, void *, void *, void *, void *);
 extern void estdep_serial(void *, void *, void *, void *, void *, void *);
 extern void Sn_serial0(void *, void *, void *, void *);
 extern void stats_nonserial(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 extern void stats_serial(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
+extern void stats_serialVectors(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 extern void stats_serial_bin(void *, void *, void *, void *, void *, void *, void *, void *);
 extern void statsim(void *, void *, void *, void *, void *, void *, void *);
 
@@ -20,6 +21,7 @@ static const R_CMethodDef CEntries[] = {
   {"Sn_serial0",       (DL_FUNC) &Sn_serial0,        4},
   {"stats_nonserial",  (DL_FUNC) &stats_nonserial,  10},
   {"stats_serial",     (DL_FUNC) &stats_serial,     10},
+  {"stats_serialVectors",(DL_FUNC) &stats_serialVectors,     11},
   {"stats_serial_bin", (DL_FUNC) &stats_serial_bin,  8},
   {"statsim",          (DL_FUNC) &statsim,           7},
   {NULL, NULL, 0}
